/* Copyright 2020 Purdea Andrei
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include QMK_KEYBOARD_H

// Defines names for use in layer keycodes and the keymap
enum layer_names {
    _BASE,
    _FN,
    _FN2
};

// Defines the keycodes used by our macros in process_record_user
enum custom_keycodes {
    QMKBEST = SAFE_RANGE,
    QMKURL,
    QMKADM,
    QMKSTD,
    QMKROL,
    QMKFLY,
    QMKHOM,
    QMKSSH,
    QMKVIM,
    QMKMAK,
    QMKCPY
};

// Tap Dance declarations
// Tap Dance declarations
enum {
	    TD_ESC_CAPS,
	    TD_RSFT_UP,
	    TD_RGUI_LEFT,
	    TD_RALT_RGHT,
	    TD_GRV_HOME,
	    TD_BSLS_END,
	    TD_LBRC_PGUP,
	    TD_QUOT_PGDN,
};

// Tap Dance definitions
qk_tap_dance_action_t tap_dance_actions[] = {
       // Tap once for Escape, twice for Caps Lock
       [TD_ESC_CAPS] = ACTION_TAP_DANCE_DOUBLE(KC_ESC, KC_CAPS),
       [TD_RSFT_UP] = ACTION_TAP_DANCE_DOUBLE(KC_RSFT, KC_UP),
       [TD_RGUI_LEFT] = ACTION_TAP_DANCE_DOUBLE(KC_RGUI, KC_LEFT),
       [TD_RALT_RGHT] = ACTION_TAP_DANCE_DOUBLE(KC_RALT, KC_RGHT),
       [TD_GRV_HOME] = ACTION_TAP_DANCE_DOUBLE(KC_GRV, KC_HOME),
       [TD_BSLS_END] = ACTION_TAP_DANCE_DOUBLE(KC_BSLS, KC_END),
       [TD_LBRC_PGUP] = ACTION_TAP_DANCE_DOUBLE(KC_LBRC, KC_PGUP),
       [TD_QUOT_PGDN] = ACTION_TAP_DANCE_DOUBLE(KC_QUOT, KC_PGDN),
};


const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
    /* Base */
    [_BASE] = LAYOUT_ansi_nonhhkb_split_shift_split_backspace(
	KC_ESC,  KC_1,    KC_2,    KC_3,    KC_4,    KC_5,    KC_6,    KC_7,    KC_8,    KC_9,    KC_0,     KC_MINS,          KC_EQL,  TD(TD_GRV_HOME), TD(TD_BSLS_END),
	KC_TAB,  KC_Q,    KC_W,    KC_E,    KC_R,    KC_T,    KC_Y,    KC_U,    KC_I,    KC_O,    KC_P,     TD(TD_LBRC_PGUP), KC_RBRC, KC_BSPC,
	KC_LCTL, KC_A,    KC_S,    KC_D,    KC_F,    KC_G,    KC_H,    KC_J,    KC_K,    KC_L,    KC_SCLN,  TD(TD_QUOT_PGDN),  KC_ENT,
	KC_LSFT, KC_Z,    KC_X,    KC_C,    KC_V,    KC_B,    KC_N,    KC_M,    KC_COMM, KC_DOT,  KC_SLSH,  TD(TD_RSFT_UP),   TT(2),
	KC_LALT, MO(_FN), KC_LGUI,                      KC_SPC,                TD(TD_RGUI_LEFT),  KC_DOWN,  TD(TD_RALT_RGHT)
    ),


    [_FN] = LAYOUT_ansi_nonhhkb_split_shift_split_backspace(
    	HPT_TOG, KC_F1,   KC_F2,   KC_F3,   KC_F4,   KC_F5,   KC_F6,   KC_F7,   KC_F8,   KC_F9,   KC_F10,   KC_F11,           KC_F12,   KC_HOME, KC_END,
	KC_TAB,  QMKBEST, KC_NO,   KC_NO,   QMKROL,  KC_NO,   KC_NO,   KC_NO,   KC_NO,   KC_NO,   KC_NO,    KC_PGUP,          KC_NO,    KC_DEL,
	KC_LCTL, QMKADM,  QMKSTD,  KC_NO,   QMKLY,  KC_NO,   QMKHOM,  KC_NO,   RESET,   KC_NO,   KC_NO,    KC_PGDN,           KC_NO,
	KC_LSFT, QMKSSH,  QMKVIM,  QMKMAK,  QMKCPY,  KC_F14,  KC_F15,  KC_MUTE, KC_VOLD, KC_VOLU, KC_NO,    KC_UP,            KC_TRNS,
	KC_LALT, KC_TRNS, KC_LGUI,                      KC_SPC,              KC_LEFT, KC_DOWN, KC_RGHT
    ),


    [_FN2] = LAYOUT_ansi_nonhhkb_split_shift_split_backspace(
        KC_ESC,  KC_1,    KC_2,    KC_3,    KC_4,    KC_5,    KC_6,    KC_7,    KC_8,    KC_9,    KC_0,     KC_MINS,          KC_EQL,  TD(TD_GRV_HOME), TD(TD_BSLS_END),
        KC_TAB,  KC_Q,    KC_W,    KC_E,    KC_R,    KC_T,    KC_Y,    KC_U,    KC_I,    KC_O,    KC_P,     TD(TD_LBRC_PGUP), KC_RBRC, KC_BSPC,
        KC_LCTL, KC_A,    KC_S,    KC_D,    KC_F,    KC_G,    KC_H,    KC_J,    KC_K,    KC_L,    KC_SCLN,  TD(TD_QUOT_PGDN),  KC_ENT,
        KC_LSFT, KC_Z,    KC_X,    KC_C,    KC_V,    KC_B,    KC_N,    KC_M,    KC_COMM, KC_DOT,  KC_SLSH,  KC_UP,            TT(2),
        KC_LALT, MO(_FN), KC_LGUI,                      KC_SPC,                  KC_LEFT, KC_DOWN, KC_RGHT
    )
};

bool process_record_user(uint16_t keycode, keyrecord_t *record) {
    switch (keycode) {
        case QMKBEST:
            if (record->event.pressed) {
                // when keycode QMKBEST is pressed
                SEND_STRING("www.google.com");
            } else {
                // when keycode QMKBEST is released
            }
            break;
        case QMKROL:
            if (record->event.pressed) {
                // when keycode QMKROL is pressed
                SEND_STRING("roland.huber");
            } else {
                // when keycode QMROL is released
            }
            break;
         case QMKADM:
            if (record->event.pressed) {
                // when keycode QMKADM is pressed
                SEND_STRING("Administrator");
            } else {
                // when keycode QMKADM is released
            }
            break;
         case QMKSTD:
            if (record->event.pressed) {
                // when keycode QMKSTD is pressed
                SEND_STRING("System Operator");
            } else {
                // when keycode QMKSTD is released
            }
            break;
         case QMKFLY:
            if (record->event.pressed) {
                // when keycode QMKFYE is pressed
                SEND_STRING("FLY");
            } else {
                // when keycode QMKFYE is released
            }
            break;
         case QMKHOM:
            if (record->event.pressed) {
                // when keycode QMKHOM is pressed
                SEND_STRING("darkcruix");
            } else {
                // when keycode QMKHOM is released
            }
            break;
	 case QMKSSH:
            if (record->event.pressed) {
                // when keycode QMKSSH is pressed
                SEND_STRING("ssh sysop@mp02.space.mil");
            } else {
                // when keycode QMKSSH is released
            }
            break;
         case QMKVIM:
            if (record->event.pressed) {
                // when keycode QMKVIM is pressed
                SEND_STRING("vi ~ /qmk_firmware/keyboards/xwhatsit/brand_new_model_f/f77/wcass/keymaps/darkcruix_f77_16/keymap.c");
            } else {
                // when keycode QMKVIM is released
            }
            break;
         case QMKMAK:
            if (record->event.pressed) {
                // when keycode QMKMAK is pressed
                SEND_STRING("cd ~ /qmk_firmware\nmake xwhatsit/brand_new_model_f/f77/wcass:darkcruix_f77_16");
            } else {
                // when keycode QMKMAK is released
            }
            break;
         case QMKCPY:
            if (record->event.pressed) {
                // when keycode QMKCPY is pressed
                SEND_STRING("cp xwhatsit_brand_new_model_f_f77_wcass_darkcruix_f77_16.hex /mnt/Public/keyboard/QMK/F77-16/.");
            } else {
                // when keycode QMKCPY is released
            }
            break;
    }
    return true;
}


/*
void matrix_init_user(void) {
}

void matrix_scan_user(void) {

}

bool led_update_user(led_t led_state) {
    return true;
}
*/
